==> nbdkit_1.36.3.orig.tar.gz: nbdkit-1.36.3/tests/test-curl-header-script-fail.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Test the curl plugin header-script error path.  Although we are
# using the file plugin (and so no headers would be sent) the header
# script should still be run once.  We want to check that if it fails
# then nbdkit correctly logs the error message.

source ./functions.sh
set -e
set -x

requires_run
requires test -f disk
requires_nbdinfo

errors="test-curl-header-script-fail.log"
rm -f $errors
cleanup_fn rm -f $errors

# This command is expected to fail.
nbdkit -rfv \
       curl file:$PWD/disk protocols=file \
       header-script=$PWD/test-curl-header-script-fail.script \
       --run 'nbdinfo --no-content $uri' >$errors 2>&1 ||:

cat $errors

grep 'header-script failed: TEST MESSAGE TEST MESSAGE' $errors

==> nbdkit_1.42.9.orig.tar.gz: nbdkit-1.42.9/tests/test-curl-header-script-fail.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Test the curl plugin header-script error path.  Although we are
# using the file plugin (and so no headers would be sent) the header
# script should still be run once.  We want to check that if it fails
# then nbdkit correctly logs the error message.

source ./functions.sh
set -e
set -x

requires_run
requires test -f disk
requires_nbdinfo
requires_curl_protocol file

errors="test-curl-header-script-fail.log"
rm -f $errors
cleanup_fn rm -f $errors

# This command is expected to fail.
nbdkit -rfv \
       curl file:$PWD/disk protocols=file \
       header-script=$abs_top_srcdir/tests/test-curl-header-script-fail.script \
       --run 'nbdinfo --no-content $uri' >$errors 2>&1 ||:

cat $errors

grep 'header-script failed: TEST MESSAGE TEST MESSAGE' $errors
